/*
File: GroupEventMessage.java
Date		Author		Changes
Jan 22 98	Lukasz Beca	Created
*/

package webwisdom.tango.messages;

import webwisdom.tango.messages.Message;
import webwisdom.tango.consts.Const;
import java.io.*;

/**
 * A class representing message GROUP_EVENT
 * 
 *@author Lukasz Beca
 *@see Central Server - Local Demon protocol
 **/

public class GroupEventMessage extends Message {
  
  private int AID;
  private int len;
  private byte data[];
  private int userlist[];

  /**
   * Creates a new EVENT message
   *@param AIDparam application number
   *@param datapar table containing information
   **/

  public GroupEventMessage(int AIDpar, int userlistpar[], byte datapar[]) {

    int i;

   AID = AIDpar;
   len = datapar.length;
   data = new byte[len];
   
   userlist = new int[userlistpar.length];

   for (i = 0; i < len; i ++) {

     data[i] = datapar[i];

   }
   
   for (i = 0; i < userlistpar.length; i ++) {
   
   		userlist[i] = userlistpar[i];
   
   }
      
   type = Const.GROUP_EVENT;
  }

   /**
   * Creates a new EVENT message, information is read from the input stream
   *@param instream  input stream
   **/

  GroupEventMessage(DataInputStream instream) throws IOException {
    
		int ulen;
		int i;
 
    AID = instream.readInt();   
    ulen = instream.readInt();
		userlist = new int[ulen];

   	for (i = 0; i < ulen; i ++) {
		
			userlist[i] = instream.readInt();
		
		}

    len = instream.readInt();
    data = new byte[len];
    instream.readFully(data, 0, len);   
				
    type = Const.GROUP_EVENT;
    
  }

   /**
   * Writes EVENT message to the output stream
   *@param outstream  output stream
   **/


  void send(DataOutputStream outstream) throws IOException {
  
    int i;


    // System.out.println("Sending type GROUP_EVENT");
    outstream.writeInt(Const.GROUP_EVENT);
    //  System.out.println("Sending AID " + AID);
    outstream.writeInt(AID);
    
		//  System.out.println("Sending length of userlist table");
    outstream.writeInt(userlist.length);
    
    // System.out.println("Sending userlist table");
    for (i = 0; i < userlist.length; i ++) {
    
    		outstream.writeInt(userlist[i]);
    
    }
        
    // System.out.println("Sending length " + len);
    outstream.writeInt(len);
    //  System.out.println("Sending data ");

//      for (i = 0; i < len; i ++) {

//  	System.out.print(data[i]);
//      }

//      System.out.println("");

    outstream.write(data, 0, len);

    outstream.flush();
   
  }
  
  /**
   * Returns application number
   **/


  public int getAID() {
    
    return AID;

  }  
  /**
   * Returns length of table containing information
   **/

  public int getLen() {
    
    return len;

  }   

  /**
   * Returns reference to the table with information
   **/

  
  public byte[] getData() {
    
    return data;
  }


	public int[] getUserList() {	
	
		return userlist;
	
	}


}




